@@ -1,4 +1,4 @@
-"""Drivers and buses package for liquidctl.
+"""liquidctl buses and drivers.
 
 The typical use case of generic scripts and interfaces – including the
 liquidctl CLI – is to instantiate drivers for all known devices found on the
@@ -14,7 +14,7 @@ Is also possible to find devices compatible with a specific driver.
     for dev in KrakenTwoDriver.find_supported_devices():
         print(dev.description)
 
-Copyright (C) 2018–2021  Jonas Malaco and contributors
+Copyright Jonas Malaco and contributors
 SPDX-License-Identifier: GPL-3.0-or-later
 """
 
@@ -25,11 +25,17 @@ from liquidctl.driver.base import BaseBus, find_all_subclasses
 # automatically enabled drivers
 from liquidctl.driver import asetek
 from liquidctl.driver import asetek_pro
+from liquidctl.driver import asus_ryujin
+from liquidctl.driver import aura_led
+from liquidctl.driver import aquacomputer
+from liquidctl.driver import commander_core
 from liquidctl.driver import commander_pro
+from liquidctl.driver import coolit
 from liquidctl.driver import corsair_hid_psu
 from liquidctl.driver import hydro_platinum
 from liquidctl.driver import kraken2
 from liquidctl.driver import kraken3
+from liquidctl.driver import msi
 from liquidctl.driver import nzxt_epsu
 from liquidctl.driver import rgb_fusion2
 from liquidctl.driver import smart_device
