@@ -84,6 +84,14 @@ class CorsairHidPsu(UsbHidDriver):
             'fpowin115': (6.244705156199815e-05,  1.0234738310580973, 15.293509559389241),
             'fpowin230': (5.9413179794350966e-05, 1.0023670927127724, 15.886126793547152),
         }),
+        (0x1b1c, 0x1c23, 'Corsair HX1200i ATX 3.1', {
+            # CP-9020281-NA
+            # Certification is source for efficiency numbers https://www.cybenetics.com/evaluations/psus/2510/
+            # 115v: 10%-.8877, 20%-.91774, 50%-.92095, 100%-.88146
+            # 230v: 10%-.89881, 20%-.92956, 50%-.93047, 100%-.91292
+            'fpowin115': (9.930197967499293e-05, 1.003634953854399, 13.956713659543981),
+            'fpowin230': (4.716701557627399e-05, 1.031689131040792, 8.562560345390088),
+        }),
         (0x1b1c, 0x1c0a, 'Corsair RM650i', {
             'fpowin115': (0.00017323493381072683, 1.0047044721686030, 12.376592422281606),
             'fpowin230': (0.00012413136310310370, 1.0284317478987164,  9.465259079360674),
