@@ -428,13 +428,21 @@ class SmartDevice2(_BaseSmartDevice):
             'speed_channel_count': 3,
             'color_channel_count': 2
         }),
-        (0x1e71, 0x2011, 'NZXT RGB & Fan Controller (3+6 channels) (experimental)', {
+        (0x1e71, 0x2011, 'NZXT RGB & Fan Controller (3+6 channels)', {
             'speed_channel_count': 3,
-            'color_channel_count': 0
+            'color_channel_count': 0  # protocol changed, see #541
         }),
-        (0x1e71, 0x2019, 'NZXT RGB & Fan Controller (3+6 channels) (experimental)', {
+        (0x1e71, 0x2019, 'NZXT RGB & Fan Controller (3+6 channels)', {
             'speed_channel_count': 3,
-            'color_channel_count': 0
+            'color_channel_count': 0  # protocol changed, see #541
+        }),
+        (0x1e71, 0x201f, 'NZXT RGB & Fan Controller (3+6 channels)', {
+            'speed_channel_count': 3,
+            'color_channel_count': 0  # protocol changed, see #541
+        }),
+        (0x1e71, 0x2020, 'NZXT RGB & Fan Controller (3+6 channels)', {
+            'speed_channel_count': 3,
+            'color_channel_count': 6
         }),
     ]
 
@@ -621,8 +629,7 @@ class SmartDevice2(_BaseSmartDevice):
     def _write_colors(self, cid, mode, colors, sval, direction='forward',):
         mval, mod3, mod4, mincolors, maxcolors = self._COLOR_MODES[mode]
 
-        if not self._color_channels:
-            raise NotSupportedByDevice()
+        assert self._color_channels, "color channels should be available and enabled"
 
         color_count = len(colors)
         if maxcolors == 40:
@@ -664,7 +671,7 @@ class SmartDevice2(_BaseSmartDevice):
 
 class H1V2(SmartDevice2):
     _MATCHES = [
-        (0x1e71, 0x2015, 'NZXT H1 V2 (experimental)', {
+        (0x1e71, 0x2015, 'NZXT H1 V2', {
             'speed_channel_count': 2,
             'color_channel_count': 0
         }),
