@@ -7,7 +7,7 @@ from liquidctl.error import NotSupportedByDriver, NotSupportedByDevice
 
 D5NEXT_SAMPLE_STATUS_REPORT = bytes.fromhex(
     "00030DCB597C00010000006403FF00000051000004DC14000001E0007A98AF000"
-    "00000FFFF000041A803C169000001481ACAA3465CB804B401F4000000527FFF7F"
+    "00000FFFF000041A803C169000001481ACAA3465CB804B401F40000005213887F"
     "FF7FFF7FFF7FFF7FFF7FFF7FFF000000000000000009D27FFF00007FFF01F404B"
     "400200026016D006300000004B200D7010207B80000000000098D083A098A083A"
     "00060001000000000000000000000000011A24015E27101D4CFFBF"
@@ -43,7 +43,7 @@ D5NEXT_SAMPLE_CONTROL_REPORT = bytes.fromhex(
 
 FARBWERK360_SAMPLE_STATUS_REPORT = bytes.fromhex(
     "000141BBDE9203E80000006403FE000000110000001A150000005F0008AE3E000"
-    "00023BFC8C01AA20EFFD6A0E8A3915AEC0A3C0A470A6F09F87FFF7FFF7FFF7FFF"
+    "00023BFC8C01AA20EFFD6A0E8A3915AEC0A3C0A470A6F09F814507FFF7FFF7FFF"
     "7FFF7FFF7FFF7FFF7FFF7FFF7FFF7FFF7FFF7FFF7FFF7FFF00000000000000000"
     "00000000000000001F901FA0006000000030000004300000000000A0324000000"
     "00000000002710271027102710271003E8000003E8000003E8000003E80000000"
@@ -223,6 +223,7 @@ def test_d5next_get_status_directly(mockD5NextDevice, has_hwmon, direct_access):
 
     expected = [
         ("Liquid temperature", pytest.approx(25.1, 0.1), "°C"),
+        ("Soft. Sensor 1", pytest.approx(50, 0.1), "°C"),
         ("Pump speed", 1976, "rpm"),
         ("Pump power", pytest.approx(2.58, 0.1), "W"),
         ("Pump voltage", pytest.approx(12.02, 0.1), "V"),
@@ -251,11 +252,27 @@ def test_d5next_get_status_from_hwmon(mockD5NextDevice, tmp_path):
     (tmp_path / "curr2_input").write_text("31\n")  # Fan current
     (tmp_path / "in2_input").write_text("4990\n")  # +5V voltage
     (tmp_path / "in3_input").write_text("12040\n")  # +12V voltage
+    (tmp_path / "temp2_input").write_text("50000\n")  # Soft. Sensor 1 temperature
+    (tmp_path / "temp3_input").write_text("60000\n")  # Soft. Sensor 2 temperature
+    (tmp_path / "temp4_input").write_text("50000\n")  # Soft. Sensor 3 temperature
+    (tmp_path / "temp5_input").write_text("50000\n")  # Soft. Sensor 4 temperature
+    (tmp_path / "temp6_input").write_text("50000\n")  # Soft. Sensor 5 temperature
+    (tmp_path / "temp7_input").write_text("50000\n")  # Soft. Sensor 6 temperature
+    (tmp_path / "temp8_input").write_text("50000\n")  # Soft. Sensor 7 temperature
+    (tmp_path / "temp9_input").write_text("50000\n")  # Soft. Sensor 8 temperature
 
     got = mockD5NextDevice.get_status()
 
     expected = [
         ("Liquid temperature", pytest.approx(25.1, 0.1), "°C"),
+        ("Soft. Sensor 1", pytest.approx(50, 0.1), "°C"),
+        ("Soft. Sensor 2", pytest.approx(60, 0.1), "°C"),
+        ("Soft. Sensor 3", pytest.approx(50, 0.1), "°C"),
+        ("Soft. Sensor 4", pytest.approx(50, 0.1), "°C"),
+        ("Soft. Sensor 5", pytest.approx(50, 0.1), "°C"),
+        ("Soft. Sensor 6", pytest.approx(50, 0.1), "°C"),
+        ("Soft. Sensor 7", pytest.approx(50, 0.1), "°C"),
+        ("Soft. Sensor 8", pytest.approx(50, 0.1), "°C"),
         ("Pump speed", 1976, "rpm"),
         ("Pump power", pytest.approx(2.58, 0.1), "W"),
         ("Pump voltage", pytest.approx(12.02, 0.1), "V"),
@@ -398,6 +415,7 @@ def test_farbwerk360_get_status_directly(mockFarbwerk360Device, has_hwmon, direc
         ("Sensor 2", pytest.approx(26.3, 0.1), "°C"),
         ("Sensor 3", pytest.approx(26.7, 0.1), "°C"),
         ("Sensor 4", pytest.approx(25.5, 0.1), "°C"),
+        ("Soft. Sensor 1", pytest.approx(52.00, 0.1), "°C"),
     ]
 
     assert sorted(got) == sorted(expected)
@@ -409,6 +427,22 @@ def test_farbwerk360_get_status_from_hwmon(mockFarbwerk360Device, tmp_path):
     (tmp_path / "temp2_input").write_text("26310\n")
     (tmp_path / "temp3_input").write_text("26710\n")
     (tmp_path / "temp4_input").write_text("25520\n")
+    (tmp_path / "temp5_input").write_text("50000\n")  # Soft. Sensor 1 temperature
+    (tmp_path / "temp6_input").write_text("60000\n")  # Soft. Sensor 2 temperature
+    (tmp_path / "temp7_input").write_text("50000\n")  # Soft. Sensor 3 temperature
+    (tmp_path / "temp8_input").write_text("50000\n")  # Soft. Sensor 4 temperature
+    (tmp_path / "temp9_input").write_text("50000\n")  # Soft. Sensor 5 temperature
+    (tmp_path / "temp10_input").write_text("50000\n")  # Soft. Sensor 6 temperature
+    (tmp_path / "temp11_input").write_text("50000\n")  # Soft. Sensor 7 temperature
+    (tmp_path / "temp12_input").write_text("50000\n")  # Soft. Sensor 8 temperature
+    (tmp_path / "temp13_input").write_text("50000\n")  # Soft. Sensor 9 temperature
+    (tmp_path / "temp14_input").write_text("50000\n")  # Soft. Sensor 10 temperature
+    (tmp_path / "temp15_input").write_text("50000\n")  # Soft. Sensor 11 temperature
+    (tmp_path / "temp16_input").write_text("50000\n")  # Soft. Sensor 12 temperature
+    (tmp_path / "temp17_input").write_text("50000\n")  # Soft. Sensor 13 temperature
+    (tmp_path / "temp18_input").write_text("50000\n")  # Soft. Sensor 14 temperature
+    (tmp_path / "temp19_input").write_text("50000\n")  # Soft. Sensor 15 temperature
+    (tmp_path / "temp20_input").write_text("50000\n")  # Soft. Sensor 16 temperature
 
     got = mockFarbwerk360Device.get_status()
 
@@ -417,6 +451,22 @@ def test_farbwerk360_get_status_from_hwmon(mockFarbwerk360Device, tmp_path):
         ("Sensor 2", pytest.approx(26.3, 0.1), "°C"),
         ("Sensor 3", pytest.approx(26.7, 0.1), "°C"),
         ("Sensor 4", pytest.approx(25.5, 0.1), "°C"),
+        ("Soft. Sensor 1", pytest.approx(50, 0.1), "°C"),
+        ("Soft. Sensor 2", pytest.approx(60, 0.1), "°C"),
+        ("Soft. Sensor 3", pytest.approx(50, 0.1), "°C"),
+        ("Soft. Sensor 4", pytest.approx(50, 0.1), "°C"),
+        ("Soft. Sensor 5", pytest.approx(50, 0.1), "°C"),
+        ("Soft. Sensor 6", pytest.approx(50, 0.1), "°C"),
+        ("Soft. Sensor 7", pytest.approx(50, 0.1), "°C"),
+        ("Soft. Sensor 8", pytest.approx(50, 0.1), "°C"),
+        ("Soft. Sensor 9", pytest.approx(50, 0.1), "°C"),
+        ("Soft. Sensor 10", pytest.approx(50, 0.1), "°C"),
+        ("Soft. Sensor 11", pytest.approx(50, 0.1), "°C"),
+        ("Soft. Sensor 12", pytest.approx(50, 0.1), "°C"),
+        ("Soft. Sensor 13", pytest.approx(50, 0.1), "°C"),
+        ("Soft. Sensor 14", pytest.approx(50, 0.1), "°C"),
+        ("Soft. Sensor 15", pytest.approx(50, 0.1), "°C"),
+        ("Soft. Sensor 16", pytest.approx(50, 0.1), "°C"),
     ]
 
     assert sorted(got) == sorted(expected)
@@ -491,13 +541,12 @@ def test_octo_get_status_directly(mockOctoDevice, has_hwmon, direct_access):
 
     got = mockOctoDevice.get_status(direct_access=direct_access)
 
-    print(f"octo: got: {got}")
-
     expected = [
         ("Sensor 1", pytest.approx(27.5, 0.1), "°C"),
         ("Sensor 2", pytest.approx(27.7, 0.1), "°C"),
         ("Sensor 3", pytest.approx(28.4, 0.1), "°C"),
         ("Sensor 4", pytest.approx(34.2, 0.1), "°C"),
+        ("Soft. Sensor 1", pytest.approx(37.84, 0.1), "°C"),
         ("Fan 1 speed", pytest.approx(0, 0.1), "rpm"),
         ("Fan 1 power", pytest.approx(0.01, 0.1), "W"),
         ("Fan 1 voltage", pytest.approx(12.09, 0.1), "V"),
@@ -573,6 +622,22 @@ def test_octo_get_status_from_hwmon(mockOctoDevice, tmp_path):
     (tmp_path / "power8_input").write_text("20000\n")
     (tmp_path / "in7_input").write_text("12090\n")
     (tmp_path / "curr8_input").write_text("2\n")
+    (tmp_path / "temp5_input").write_text("50000\n")  # Soft. Sensor 1 temperature
+    (tmp_path / "temp6_input").write_text("60000\n")  # Soft. Sensor 2 temperature
+    (tmp_path / "temp7_input").write_text("50000\n")  # Soft. Sensor 3 temperature
+    (tmp_path / "temp8_input").write_text("50000\n")  # Soft. Sensor 4 temperature
+    (tmp_path / "temp9_input").write_text("50000\n")  # Soft. Sensor 5 temperature
+    (tmp_path / "temp10_input").write_text("50000\n")  # Soft. Sensor 6 temperature
+    (tmp_path / "temp11_input").write_text("50000\n")  # Soft. Sensor 7 temperature
+    (tmp_path / "temp12_input").write_text("50000\n")  # Soft. Sensor 8 temperature
+    (tmp_path / "temp13_input").write_text("50000\n")  # Soft. Sensor 9 temperature
+    (tmp_path / "temp14_input").write_text("50000\n")  # Soft. Sensor 10 temperature
+    (tmp_path / "temp15_input").write_text("50000\n")  # Soft. Sensor 11 temperature
+    (tmp_path / "temp16_input").write_text("50000\n")  # Soft. Sensor 12 temperature
+    (tmp_path / "temp17_input").write_text("50000\n")  # Soft. Sensor 13 temperature
+    (tmp_path / "temp18_input").write_text("50000\n")  # Soft. Sensor 14 temperature
+    (tmp_path / "temp19_input").write_text("50000\n")  # Soft. Sensor 15 temperature
+    (tmp_path / "temp20_input").write_text("50000\n")  # Soft. Sensor 16 temperature
 
     got = mockOctoDevice.get_status()
 
@@ -613,6 +678,22 @@ def test_octo_get_status_from_hwmon(mockOctoDevice, tmp_path):
         ("Fan 8 power", pytest.approx(0.02, 0.1), "W"),
         ("Fan 8 voltage", pytest.approx(12.09, 0.1), "V"),
         ("Fan 8 current", pytest.approx(0.002, 0.1), "A"),
+        ("Soft. Sensor 1", pytest.approx(50, 0.1), "°C"),
+        ("Soft. Sensor 2", pytest.approx(60, 0.1), "°C"),
+        ("Soft. Sensor 3", pytest.approx(50, 0.1), "°C"),
+        ("Soft. Sensor 4", pytest.approx(50, 0.1), "°C"),
+        ("Soft. Sensor 5", pytest.approx(50, 0.1), "°C"),
+        ("Soft. Sensor 6", pytest.approx(50, 0.1), "°C"),
+        ("Soft. Sensor 7", pytest.approx(50, 0.1), "°C"),
+        ("Soft. Sensor 8", pytest.approx(50, 0.1), "°C"),
+        ("Soft. Sensor 9", pytest.approx(50, 0.1), "°C"),
+        ("Soft. Sensor 10", pytest.approx(50, 0.1), "°C"),
+        ("Soft. Sensor 11", pytest.approx(50, 0.1), "°C"),
+        ("Soft. Sensor 12", pytest.approx(50, 0.1), "°C"),
+        ("Soft. Sensor 13", pytest.approx(50, 0.1), "°C"),
+        ("Soft. Sensor 14", pytest.approx(50, 0.1), "°C"),
+        ("Soft. Sensor 15", pytest.approx(50, 0.1), "°C"),
+        ("Soft. Sensor 16", pytest.approx(50, 0.1), "°C"),
     ]
 
     assert sorted(got) == sorted(expected)
@@ -741,6 +822,8 @@ def test_quadro_get_status_directly(mockQuadroDevice, has_hwmon, direct_access):
 
     expected = [
         ("Sensor 3", pytest.approx(16.17, 0.1), "°C"),
+        ("Soft. Sensor 1", pytest.approx(23.9, 0.1), "°C"),
+        ("Soft. Sensor 13", pytest.approx(50.0, 0.1), "°C"),
         ("Fan 1 speed", pytest.approx(0, 0.1), "rpm"),
         ("Fan 1 power", pytest.approx(0, 0.1), "W"),
         ("Fan 1 voltage", pytest.approx(0, 0.1), "V"),
@@ -786,6 +869,22 @@ def test_quadro_get_status_from_hwmon(mockQuadroDevice, tmp_path):
     (tmp_path / "in3_input").write_text("0\n")
     (tmp_path / "curr4_input").write_text("0\n")
     (tmp_path / "fan5_input").write_text("603\n")
+    (tmp_path / "temp5_input").write_text("50000\n")  # Soft. Sensor 1 temperature
+    (tmp_path / "temp6_input").write_text("60000\n")  # Soft. Sensor 2 temperature
+    (tmp_path / "temp7_input").write_text("50000\n")  # Soft. Sensor 3 temperature
+    (tmp_path / "temp8_input").write_text("50000\n")  # Soft. Sensor 4 temperature
+    (tmp_path / "temp9_input").write_text("50000\n")  # Soft. Sensor 5 temperature
+    (tmp_path / "temp10_input").write_text("50000\n")  # Soft. Sensor 6 temperature
+    (tmp_path / "temp11_input").write_text("50000\n")  # Soft. Sensor 7 temperature
+    (tmp_path / "temp12_input").write_text("50000\n")  # Soft. Sensor 8 temperature
+    (tmp_path / "temp13_input").write_text("50000\n")  # Soft. Sensor 9 temperature
+    (tmp_path / "temp14_input").write_text("50000\n")  # Soft. Sensor 10 temperature
+    (tmp_path / "temp15_input").write_text("50000\n")  # Soft. Sensor 11 temperature
+    (tmp_path / "temp16_input").write_text("50000\n")  # Soft. Sensor 12 temperature
+    (tmp_path / "temp17_input").write_text("50000\n")  # Soft. Sensor 13 temperature
+    (tmp_path / "temp18_input").write_text("50000\n")  # Soft. Sensor 14 temperature
+    (tmp_path / "temp19_input").write_text("50000\n")  # Soft. Sensor 15 temperature
+    (tmp_path / "temp20_input").write_text("50000\n")  # Soft. Sensor 16 temperature
 
     got = mockQuadroDevice.get_status()
 
@@ -811,6 +910,22 @@ def test_quadro_get_status_from_hwmon(mockQuadroDevice, tmp_path):
         ("Fan 4 voltage", pytest.approx(0, 0.1), "V"),
         ("Fan 4 current", pytest.approx(0, 0.1), "A"),
         ("Flow sensor", pytest.approx(603, 0.1), "dL/h"),
+        ("Soft. Sensor 1", pytest.approx(50, 0.1), "°C"),
+        ("Soft. Sensor 2", pytest.approx(60, 0.1), "°C"),
+        ("Soft. Sensor 3", pytest.approx(50, 0.1), "°C"),
+        ("Soft. Sensor 4", pytest.approx(50, 0.1), "°C"),
+        ("Soft. Sensor 5", pytest.approx(50, 0.1), "°C"),
+        ("Soft. Sensor 6", pytest.approx(50, 0.1), "°C"),
+        ("Soft. Sensor 7", pytest.approx(50, 0.1), "°C"),
+        ("Soft. Sensor 8", pytest.approx(50, 0.1), "°C"),
+        ("Soft. Sensor 9", pytest.approx(50, 0.1), "°C"),
+        ("Soft. Sensor 10", pytest.approx(50, 0.1), "°C"),
+        ("Soft. Sensor 11", pytest.approx(50, 0.1), "°C"),
+        ("Soft. Sensor 12", pytest.approx(50, 0.1), "°C"),
+        ("Soft. Sensor 13", pytest.approx(50, 0.1), "°C"),
+        ("Soft. Sensor 14", pytest.approx(50, 0.1), "°C"),
+        ("Soft. Sensor 15", pytest.approx(50, 0.1), "°C"),
+        ("Soft. Sensor 16", pytest.approx(50, 0.1), "°C"),
     ]
 
     assert sorted(got) == sorted(expected)
