@@ -1,8 +1,10 @@
 import pytest
-from collections import deque
-from liquidctl.driver.rgb_fusion2 import RgbFusion2
 from _testutils import MockHidapiDevice, Report
 
+from collections import deque
+
+from liquidctl.driver.rgb_fusion2 import RgbFusion2
+
 # Sample data for 5702 controller from a Gigabyte Z490 Vision D
 # https://github.com/liquidctl/liquidctl/issues/151#issuecomment-663213956
 _INIT_5702_DATA = bytes.fromhex(
@@ -111,8 +113,8 @@ def test_fusion2_5702_device_flash_with_some_channel_and_speed(mockRgbFusion2_57
 
 def test_fusion2_5702_device_double_flash_with_some_channel_and_speed_and_uppercase(mockRgbFusion2_5702Device):
     colors = [[0xff, 0, 0x80], [0x30, 0x30, 0x30]]  # second color should be ignored
-    mockRgbFusion2_5702Device.set_color(channel='LED5', mode='DOUBLE-FLASH', colors=iter(colors),
-                                        speed='LUDICROUS')
+    mockRgbFusion2_5702Device.set_color(channel='led5', mode='double-flash', colors=iter(colors),
+                                        speed='ludicrous')
     set_color, execute = mockRgbFusion2_5702Device.device.sent
 
     assert set_color.data[0:2] == [0x24, 0x10]
